@@ -88,6 +88,9 @@ MA90 = 'MA90'
 MA128 = 'MA128'
 MA200 = 'MA200'
 
+# SOPR
+SOPR = 'SOPR'
+
 # Misc
 POLY_CRYPTO_SYMBOLS = [
     'X%3ABTCUSD', 'X%3AETHUSD',
@@ -187,6 +190,12 @@ class PathFinder:
             'diff_ribbon.csv'
         )
 
+    def get_sopr_path(self):
+        return os.path.join(
+            DATA_DIR,
+            'sopr.csv'
+        )
+
     def get_all_paths(self, path, truncate=False):
         # given a path, get all sub paths
         paths = []
